@@ -10,7 +10,7 @@ from .enums import OptionType, PermissionType
 
 from discord import ui, http
 from aiohttp.client import ClientSession
-from discord.utils import cached_property
+from discord.utils import cached_property, copy_doc
 from typing import (
     Any,
     Dict,
@@ -445,6 +445,10 @@ class InteractionContext:
 
         return self.channel.send(*args, **kwargs)
 
+    @copy_doc(respond)
+    def reply(self, *args, **kwargs):
+        return self.respond(*args, **kwargs)
+
     def defer(self, *args, **kwargs):
         """|coro|
 
